# 1. NNmeta

- [1. NNmeta](#1-NNmeta)
  - [1.1. Usage](#11-usage)
  - [1.2. Contribution](#12-contribution)
  - [License](#-license)


NN class for any purpose. Created for internal needs. Feel free to use it and contribute (see [contribution section](#12-contribution)).

## 1.1. Usage

Soon.

## 1.2. Contribution

Feel free to contribute to the project, but please create initially an issue with detailed problem and way to resolve it. 

## License
----

MIT
